@@ -391,15 +391,18 @@ class EvalException(object):
             res.body = 'The module <code>%s</code> does not have an entry in sys.modules' % module_name
             return res
         filename = module.__file__
-        if filename.endswith('.pyc'):
+        if filename[-4:] in ('.pyc', '.pyo'):
             filename = filename[:-1]
+        elif filename.endswith('$py.class'):
+            filename = '%s.py' % filename[:-9]
         f = open(filename, 'rb')
         source = f.read()
         f.close()
         html = (
             ('<div>Module: <b>%s</b> file: %s</div>'
-             % (module_name, filename))
-            + formatter.highlight_python(source, linenos=True))
+             '<style type="text/css">%s</style>'
+             % (module_name, filename, formatter.pygments_css))
+            + formatter.highlight(filename, source, linenos=True))
         source_lines = len(source.splitlines())
         if source_lines < 60:
             html += '\n<br>'*(60-source_lines)
@@ -459,7 +462,7 @@ class EvalException(object):
             exc_data = collector.collect_exception(*exc_info)
             exc_data.view_url = view_uri
             if self.reporters:
-                for reporter in reporters:
+                for reporter in self.reporters:
                     reporter.report(exc_data)
             debug_info = DebugInfo(count, exc_info, exc_data, base_path,
                                    environ, view_uri, self.error_template,
